@@ -149,6 +149,8 @@
 
                 EXPORT1(compressor_x2_gain)
                 EXPORT1(compressor_x2_curve)
+                EXPORT1(gate_x1_gain)
+                EXPORT1(gate_x1_curve)
             }
 
             #undef EXPORT1
